@@ -2,11 +2,11 @@
 #' @export
 #' @family packages
 #' @description List all the paths to the Stan model files in a package.
-#' @details All Stan models must live in the `inst/stan/` directory in the
+#' @details All Stan models must live in the `src/stan/` directory in the
 #'   package file system.
 #' @return Character vector of paths to Stan model files in the package.
-#' @param path Character of length 1, path to the root directory of the
-#'   R package with the Stan models.
+#' @param path Character of length 1, root path to start from when searching
+#'   for Stan model files.
 #' @examples
 #' path <- tempfile()
 #' stan_package_create(path = path)
@@ -20,8 +20,12 @@ stan_package_model_files <- function(path = getwd()) {
     length(.) == 1L,
     message = "invalid package directory path in stan_package_model_files()"
   )
-  path <- file.path(path, "inst", "stan")
-  out <- list.files(path, full.names = TRUE, pattern = "\\.stan$")
+  out <- list.files(
+    path,
+    full.names = TRUE,
+    recursive = TRUE,
+    pattern = "\\.stan$"
+  )
   stan_assert(
     length(out) > 0L,
     message = paste0(
