@@ -24,6 +24,11 @@ if (!file.exists(bin)) {
 }
 bin_stan <- file.path(bin, "stan")
 fs::dir_copy(path = "stan", new_path = bin_stan)
-instantiate::stan_package_compile(
-  models = instantiate::stan_package_model_files(path = bin_stan)
+callr::r(
+  func = function(bin_stan) {
+    instantiate::stan_package_compile(
+      models = instantiate::stan_package_model_files(path = bin_stan)
+    )
+  },
+  args = list(bin_stan = bin_stan)
 )
