@@ -3,6 +3,6 @@ stan_test("stan_package_create()", {
   path <- "package"
   stan_package_create(path = path)
   expect_true(file.exists(file.path(path, "DESCRIPTION")))
-  expect_true(file.exists(file.path(path, "inst", "stan", "bernoulli.stan")))
+  expect_true(file.exists(file.path(path, "src", "stan", "bernoulli.stan")))
   expect_error(stan_package_create(path = path), class = "stan_error")
 })
